@@ -33,8 +33,7 @@ logger = logging.getLogger(__name__)
 
 
 class Connection(object):
-    """ Class to encapsulate connection semantics for PostgresSQL DBI connection for CockroachDB.
-    """
+    """Class to encapsulate connection semantics for PostgresSQL DBI connection for CockroachDB."""
 
     def __init__(self, cfgOb=None, infoD=None, resourceName=None, sectionName="site_info_configuration", verbose=False):
         self.__verbose = verbose
@@ -118,9 +117,9 @@ class Connection(object):
         #
 
     def connect(self):
-        """ Create a database connection and return a connection object.
+        """Create a database connection and return a connection object.
 
-            Returns None on failure
+        Returns None on failure
         """
         #
         if self.__dbcon is not None:
@@ -143,8 +142,7 @@ class Connection(object):
         return self.__dbcon
 
     def close(self):
-        """ Close any open database connection.
-        """
+        """Close any open database connection."""
         if self.__dbcon is not None:
             try:
                 self.__dbcon.close()
